AssistantService class

Constructors

AssistantService()

Properties

baseText String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
language String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAssistants(String apiKey) Future<List<Assistant>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
useAssistants(String apiKey, List<Assistant> assistants, String transcript) Future<List<Map<String, dynamic>>>

Operators

operator ==(Object other) bool
The equality operator.
inherited