CalibrationService class

Constructors

CalibrationService({required AudioRecorder recorder})

Properties

baseText String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
language String
getter/setter pair
recorder → AudioRecorder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCalibration(String baseTextTranscript, String? languageChange) Future<bool>
stopCalibration(String apiKey) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited