RecordService class

Constructors

RecordService({required AudioRecorder recorder})

Properties

hashCode int
The hash code for this object.
no setterinherited
recorder → AudioRecorder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelAudio() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startRecord(Map<String, dynamic>? userCalibrationData) Future<bool>
stopRecord(String apiKey, String language) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited