LocalVoiceCopilot class
- Inheritance
-
- Object
- PlatformInterface
- VoiceCopilotPlatform
- LocalVoiceCopilot
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelAudio(
) → Future< bool> -
override
-
getAssistants(
String apiKey) → Future< List< Assistant> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startCalibration(
String baseTextTranscript, String? languageChange) → Future< bool> -
override
-
startRecord(
Map< String, dynamic> ? params) → Future<bool> -
override
-
stopCalibration(
String apiKey) → Future< Map< String, dynamic> > -
override
-
stopRecord(
String apiKey, String language) → Future< Map< String, dynamic> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
useAssistants(
String apiKey, List< Assistant> assistants, String transcript) → Future<List< Map< >String, dynamic> > -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited